Build status as of Thu Aug 6 06:00:01 2009

2009-08-05 Thread build
URL: http://build.samba.org/

--- /home/build/master/cache/broken_results.txt.old 2009-08-05 
00:00:06.0 -0600
+++ /home/build/master/cache/broken_results.txt 2009-08-06 00:00:11.0 
-0600
@@ -1,22 +1,22 @@
-Build status as of Wed Aug  5 06:00:01 2009
+Build status as of Thu Aug  6 06:00:01 2009
 
 Build counts:
 Tree Total  Broken Panic 
 build_farm   0  0  0 
-ccache   3  1  0 
+ccache   23 6  0 
 distcc   0  0  0 
 ldb  32 32 0 
 libreplace   2  0  0 
 lorikeet 0  0  0 
 pidl 3  0  0 
-ppp  1  0  0 
-rsync32 13 0 
+ppp  8  0  0 
+rsync4  2  0 
 samba-docs   0  0  0 
 samba-web0  0  0 
-samba_3_current 28 17 0 
-samba_3_master 29 29 0 
-samba_3_next 29 25 1 
-samba_4_0_test 31 25 5 
+samba_3_current 29 17 0 
+samba_3_master 29 26 6 
+samba_3_next 29 26 2 
+samba_4_0_test 32 27 2 
 talloc   4  4  0 
-tdb  4  4  0 
+tdb  25 25 0 
 


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha8-850-g252f7da

2009-08-05 Thread Andrew Tridgell
The branch, master has been updated
   via  252f7da702fd0409f7bfff05ef594911ededa32f (commit)
  from  740a40e74eb79234e1c40ca88768202b3c0af2b9 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 252f7da702fd0409f7bfff05ef594911ededa32f
Author: Rusty Russell 
Date:   Thu Aug 6 13:13:42 2009 +1000

There is one signedness issue in tdb which prevents traverses of TDB records
over the 2G offset on systems which support 64 bit file offsets.  This fixes
that case.

On systems with 32 bit offsets, expansion and fcntl locking on these records
will fail anyway.  SAMBA already does '#define _FILE_OFFSET_BITS 64' in
config.h (on my 32-bit x86 Linux system at least) to get 64 bit file 
offsets.

Signed-off-by: Rusty Russell 

---

Summary of changes:
 lib/tdb/common/traverse.c |   30 +-
 1 files changed, 21 insertions(+), 9 deletions(-)


Changeset truncated at 500 lines:

diff --git a/lib/tdb/common/traverse.c b/lib/tdb/common/traverse.c
index 07b0c23..8e5a63a 100644
--- a/lib/tdb/common/traverse.c
+++ b/lib/tdb/common/traverse.c
@@ -27,8 +27,11 @@
 
 #include "tdb_private.h"
 
-/* Uses traverse lock: 0 = finish, -1 = error, other = record offset */
-static int tdb_next_lock(struct tdb_context *tdb, struct tdb_traverse_lock 
*tlock,
+#define TDB_NEXT_LOCK_ERR ((tdb_off_t)-1)
+
+/* Uses traverse lock: 0 = finish, TDB_NEXT_LOCK_ERR = error,
+   other = record offset */
+static tdb_off_t tdb_next_lock(struct tdb_context *tdb, struct 
tdb_traverse_lock *tlock,
 struct list_struct *rec)
 {
int want_next = (tlock->off != 0);
@@ -71,7 +74,7 @@ static int tdb_next_lock(struct tdb_context *tdb, struct 
tdb_traverse_lock *tloc
}
 
if (tdb_lock(tdb, tlock->hash, tlock->lock_rw) == -1)
-   return -1;
+   return TDB_NEXT_LOCK_ERR;
 
/* No previous record?  Start at top of chain. */
if (!tlock->off) {
@@ -99,6 +102,7 @@ static int tdb_next_lock(struct tdb_context *tdb, struct 
tdb_traverse_lock *tloc
 
/* Detect infinite loops. From "Shlomi Yaakobovich" 
. */
if (tlock->off == rec->next) {
+   tdb->ecode = TDB_ERR_CORRUPT;
TDB_LOG((tdb, TDB_DEBUG_FATAL, "tdb_next_lock: 
loop detected.\n"));
goto fail;
}
@@ -127,7 +131,7 @@ static int tdb_next_lock(struct tdb_context *tdb, struct 
tdb_traverse_lock *tloc
tlock->off = 0;
if (tdb_unlock(tdb, tlock->hash, tlock->lock_rw) != 0)
TDB_LOG((tdb, TDB_DEBUG_FATAL, "tdb_next_lock: On error unlock 
failed!\n"));
-   return -1;
+   return TDB_NEXT_LOCK_ERR;
 }
 
 /* traverse the entire database - calling fn(tdb, key, data) on each element.
@@ -141,7 +145,8 @@ static int tdb_traverse_internal(struct tdb_context *tdb,
 {
TDB_DATA key, dbuf;
struct list_struct rec;
-   int ret, count = 0;
+   int ret = 0, count = 0;
+   tdb_off_t off;
 
/* This was in the initializaton, above, but the IRIX compiler
 * did not like it.  crh
@@ -152,7 +157,11 @@ static int tdb_traverse_internal(struct tdb_context *tdb,
tdb->travlocks.next = tl;
 
/* tdb_next_lock places locks on the record returned, and its chain */
-   while ((ret = tdb_next_lock(tdb, tl, &rec)) > 0) {
+   while ((off = tdb_next_lock(tdb, tl, &rec)) != 0) {
+   if (off == TDB_NEXT_LOCK_ERR) {
+   ret = -1;
+   goto out;
+   }
count++;
/* now read the full record */
key.dptr = tdb_alloc_read(tdb, tl->off + sizeof(rec), 
@@ -177,7 +186,6 @@ static int tdb_traverse_internal(struct tdb_context *tdb,
}
if (fn && fn(tdb, key, dbuf, private_data)) {
/* They want us to terminate traversal */
-   ret = count;
if (tdb_unlock_record(tdb, tl->off) != 0) {
TDB_LOG((tdb, TDB_DEBUG_FATAL, "tdb_traverse: 
unlock_record failed!\n"));;
ret = -1;
@@ -256,6 +264,7 @@ TDB_DATA tdb_firstkey(struct tdb_context *tdb)
 {
TDB_DATA key;
struct list_struct rec;
+   tdb_off_t off;
 
/* release any old lock */
if (tdb_unlock_record(tdb, tdb->travlocks.off) != 0)
@@ -264,7 +273,8 @@ TDB_DATA tdb_firstkey(struct tdb_context *tdb)
tdb->travlocks.lock_rw = F_RDLCK;
 
/* Grab first record: locks chain and returned record. */
-   if (tdb_next_lock(tdb, &tdb->travlocks, &rec) <= 0)
+   off = tdb_next_lock(tdb, &tdb->travloc

[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha8-849-g740a40e

2009-08-05 Thread Andrew Tridgell
The branch, master has been updated
   via  740a40e74eb79234e1c40ca88768202b3c0af2b9 (commit)
  from  57da47c1bd76157a6a403154551645c16ad64a75 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 740a40e74eb79234e1c40ca88768202b3c0af2b9
Author: Andrew Tridgell 
Date:   Thu Aug 6 11:36:52 2009 +1000

Revert "deliberately break the build"

This reverts commit 57da47c1bd76157a6a403154551645c16ad64a75.

The build emails do work :-)

---

Summary of changes:
 source4/Makefile |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source4/Makefile b/source4/Makefile
index 28c2468..24e58bc 100644
--- a/source4/Makefile
+++ b/source4/Makefile
@@ -161,7 +161,7 @@ libraries:: $(STATIC_LIBS) $(SHARED_LIBS)
 modules:: $(PLUGINS)
 headers:: $(PUBLIC_HEADERS)
 manpages:: $(MANPAGES)
-all:: DELIBERATEBUILDBREAKAGE showflags $(ALL_PREDEP) binaries modules 
pythonmods libraries headers
+all:: showflags $(ALL_PREDEP) binaries modules pythonmods libraries headers
 everything:: all
 
 LD_LIBPATH_OVERRIDE = $(LIB_PATH_VAR)=$(shliboutputdir):$$$(LIB_PATH_VAR)


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha8-848-g57da47c

2009-08-05 Thread Andrew Tridgell
The branch, master has been updated
   via  57da47c1bd76157a6a403154551645c16ad64a75 (commit)
  from  64e2b859d2ed9c2428219617c3864c64cd6ed909 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 57da47c1bd76157a6a403154551645c16ad64a75
Author: Andrew Tridgell 
Date:   Thu Aug 6 11:24:42 2009 +1000

deliberately break the build

I want to make sure that the build breakage emails are now working
correctly

---

Summary of changes:
 source4/Makefile |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source4/Makefile b/source4/Makefile
index 24e58bc..28c2468 100644
--- a/source4/Makefile
+++ b/source4/Makefile
@@ -161,7 +161,7 @@ libraries:: $(STATIC_LIBS) $(SHARED_LIBS)
 modules:: $(PLUGINS)
 headers:: $(PUBLIC_HEADERS)
 manpages:: $(MANPAGES)
-all:: showflags $(ALL_PREDEP) binaries modules pythonmods libraries headers
+all:: DELIBERATEBUILDBREAKAGE showflags $(ALL_PREDEP) binaries modules 
pythonmods libraries headers
 everything:: all
 
 LD_LIBPATH_OVERRIDE = $(LIB_PATH_VAR)=$(shliboutputdir):$$$(LIB_PATH_VAR)


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha8-847-g64e2b85

2009-08-05 Thread Andrew Bartlett
The branch, master has been updated
   via  64e2b859d2ed9c2428219617c3864c64cd6ed909 (commit)
  from  b97d85c5e4db00a6cfc0a191907e88d2623c6681 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 64e2b859d2ed9c2428219617c3864c64cd6ed909
Author: Andrew Bartlett 
Date:   Thu Aug 6 08:17:09 2009 +1000

s4:heimdal: import lorikeet-heimdal-200908052208 (commit 
370a73a74199a5a55188340906e15fd795f67a74)

This removes some of the portability changes made to code under
heimdal/

If these are still required, then we will re-add them with code under
heimdal_build/ (so that we can simply 'drop in' future heimdal
releases).

Andrew Bartlett

---

Summary of changes:
 source4/heimdal/kuser/kinit.c  |2 --
 source4/heimdal/kuser/kuser_locl.h |2 +-
 source4/heimdal/lib/gssapi/krb5/cfx.c  |9 +
 source4/heimdal/lib/hcrypto/aes.c  |3 ---
 source4/heimdal/lib/hcrypto/bn.c   |3 ---
 source4/heimdal/lib/hcrypto/des.c  |3 ---
 source4/heimdal/lib/hcrypto/dh-imath.c |2 --
 source4/heimdal/lib/hcrypto/dh.c   |2 --
 source4/heimdal/lib/hcrypto/dsa.c  |4 
 source4/heimdal/lib/hcrypto/engine.c   |4 
 source4/heimdal/lib/hcrypto/evp-hcrypto.c  |4 
 source4/heimdal/lib/hcrypto/md2.c  |4 
 source4/heimdal/lib/hcrypto/md4.c  |4 
 source4/heimdal/lib/hcrypto/md5.c  |4 
 source4/heimdal/lib/hcrypto/pkcs12.c   |4 
 source4/heimdal/lib/hcrypto/pkcs5.c|4 
 source4/heimdal/lib/hcrypto/rand-egd.c |4 
 source4/heimdal/lib/hcrypto/rand-fortuna.c |4 
 source4/heimdal/lib/hcrypto/rand-timer.c   |4 
 source4/heimdal/lib/hcrypto/rand-unix.c|4 
 source4/heimdal/lib/hcrypto/rand.c |4 
 source4/heimdal/lib/hcrypto/rc2.c  |3 ---
 source4/heimdal/lib/hcrypto/rc4.c  |4 
 source4/heimdal/lib/hcrypto/rijndael-alg-fst.c |3 ---
 source4/heimdal/lib/hcrypto/rnd_keys.c |3 ---
 source4/heimdal/lib/hcrypto/rsa-imath.c|4 
 source4/heimdal/lib/hcrypto/rsa.c  |4 
 source4/heimdal/lib/hcrypto/sha.c  |4 
 source4/heimdal/lib/hcrypto/sha256.c   |4 
 source4/heimdal/lib/hcrypto/ui.c   |3 ---
 source4/heimdal/lib/krb5/context.c |   12 
 source4/heimdal/lib/krb5/krb5_locl.h   |2 +-
 source4/heimdal/lib/roken/vis.hin  |   24 
 33 files changed, 31 insertions(+), 117 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source4/heimdal/kuser/kinit.c b/source4/heimdal/kuser/kinit.c
index 350988d..4208fa8 100644
--- a/source4/heimdal/kuser/kinit.c
+++ b/source4/heimdal/kuser/kinit.c
@@ -768,10 +768,8 @@ main (int argc, char **argv)
 setprogname (argv[0]);
 
 setlocale (LC_ALL, "");
-#if defined(HEIMDAL_LOCALEDIR)
 bindtextdomain ("heimdal_kuser", HEIMDAL_LOCALEDIR);
 textdomain("heimdal_kuser");
-#endif
 
 ret = krb5_init_context (&context);
 if (ret == KRB5_CONFIG_BADFORMAT)
diff --git a/source4/heimdal/kuser/kuser_locl.h 
b/source4/heimdal/kuser/kuser_locl.h
index eafffe9..1bf682b 100644
--- a/source4/heimdal/kuser/kuser_locl.h
+++ b/source4/heimdal/kuser/kuser_locl.h
@@ -88,7 +88,7 @@
 #include 
 #endif
 
-#ifdef HAVE_LIBINTL_H
+#ifdef LIBINTL
 #include 
 #define N_(x,y) gettext(x)
 #define NP_(x,y) (x)
diff --git a/source4/heimdal/lib/gssapi/krb5/cfx.c 
b/source4/heimdal/lib/gssapi/krb5/cfx.c
index 35e5a9e..7cc7ee1 100755
--- a/source4/heimdal/lib/gssapi/krb5/cfx.c
+++ b/source4/heimdal/lib/gssapi/krb5/cfx.c
@@ -41,10 +41,10 @@
 #define CFXAcceptorSubkey  (1 << 2)
 
 krb5_error_code
-_gsskrb5cfx_wrap_length_cfx(const gsskrb5_ctx context_handle,
-   krb5_context context,
+_gsskrb5cfx_wrap_length_cfx(krb5_context context,
krb5_crypto crypto,
int conf_req_flag,
+   int dce_style,
size_t input_length,
size_t *output_length,
size_t *cksumsize,
@@ -71,7 +71,7 @@ _gsskrb5cfx_wrap_length_cfx(const gsskrb5_ctx context_handle,
/* Header is concatenated with data before encryption */
input_length += sizeof(gss_cfx_wrap_token_desc);
 
-   if (IS_DCE_STYLE(context_handle)) {
+   if (dce_style) {
ret = krb5_crypto_getblocksize(context, crypto, &padsize);
} else {
ret = krb5_crypto_getpadsize(context, crypto, &padsize);
@@ -972,8 +972,9 @@ OM_u

[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha8-846-gb97d85c

2009-08-05 Thread Andrew Tridgell
The branch, master has been updated
   via  b97d85c5e4db00a6cfc0a191907e88d2623c6681 (commit)
  from  e2aa38a20175430ae1ef7540a8ca7cdf0c4e955e (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit b97d85c5e4db00a6cfc0a191907e88d2623c6681
Author: Andrew Tridgell 
Date:   Thu Aug 6 07:57:17 2009 +1000

set uidwrappersrcdir

this is needed for the combined build

---

Summary of changes:
 source3/samba4.mk |1 +
 1 files changed, 1 insertions(+), 0 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/samba4.mk b/source3/samba4.mk
index 653ae25..a8cebf5 100644
--- a/source3/samba4.mk
+++ b/source3/samba4.mk
@@ -88,6 +88,7 @@ libcmdlinesrcdir := $(samba4srcdir)/lib/cmdline
 poptsrcdir := $(samba4srcdir)/../lib/popt
 socketwrappersrcdir := $(samba4srcdir)/../lib/socket_wrapper
 nsswrappersrcdir := $(samba4srcdir)/../lib/nss_wrapper
+uidwrappersrcdir := $(samba4srcdir)/../lib/uid_wrapper
 libstreamsrcdir := $(samba4srcdir)/lib/stream
 libutilsrcdir := $(samba4srcdir)/../lib/util
 libtdrsrcdir := ../lib/tdr


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha8-845-ge2aa38a

2009-08-05 Thread Andrew Tridgell
The branch, master has been updated
   via  e2aa38a20175430ae1ef7540a8ca7cdf0c4e955e (commit)
  from  39b015837378b6dca72c477225444e700fe40040 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit e2aa38a20175430ae1ef7540a8ca7cdf0c4e955e
Author: Andrew Tridgell 
Date:   Thu Aug 6 07:38:43 2009 +1000

define uwrap_enabled() on Samba3

s3 doesn't use uwrap yet, but it uses some common coe in lib/, and so
needs a dummy version of the uwrap_enabled() macro

---

Summary of changes:
 source3/include/includes.h |3 +++
 1 files changed, 3 insertions(+), 0 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/include/includes.h b/source3/include/includes.h
index 8fb240f..a636716 100644
--- a/source3/include/includes.h
+++ b/source3/include/includes.h
@@ -1112,4 +1112,7 @@ void in6_addr_to_sockaddr_storage(struct sockaddr_storage 
*ss,
  struct in6_addr ip);
 #endif
 
+/* samba3 doesn't use uwrap yet */
+#define uwrap_enabled() 0
+
 #endif /* _INCLUDES_H */


-- 
Samba Shared Repository


[SCM] SAMBA-CTDB repository - branch v3-4-ctdb updated - 3.4.0-ctdb-2-1-g01a3032

2009-08-05 Thread Michael Adam
The branch, v3-4-ctdb has been updated
   via  01a3032f84287f52834e881c2c17fd6977dbc774 (commit)
  from  a87e63fef46b01d406da6b616dfd2508b07ca833 (commit)

http://gitweb.samba.org/?p=obnox/samba-ctdb.git;a=shortlog;h=v3-4-ctdb


- Log -
commit 01a3032f84287f52834e881c2c17fd6977dbc774
Author: Michael Adam 
Date:   Wed Aug 5 14:09:00 2009 +0200

v3-4-ctdb: Bump the ctdb verdor patch level to 3.

For the next release.

Michael

---

Summary of changes:
 source3/VERSION |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/VERSION b/source3/VERSION
index 7e9ec6e..d0278a0 100644
--- a/source3/VERSION
+++ b/source3/VERSION
@@ -85,7 +85,7 @@ SAMBA_VERSION_IS_GIT_SNAPSHOT=no
 #  #
 
 SAMBA_VERSION_VENDOR_SUFFIX="ctdb"
-SAMBA_VERSION_VENDOR_PATCH=2
+SAMBA_VERSION_VENDOR_PATCH=3
 
 
 # This can be set by vendors if they want..#


-- 
SAMBA-CTDB repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha8-843-g3854b5e

2009-08-05 Thread Andrew Tridgell
The branch, master has been updated
   via  3854b5e6146ff8efeb4379a502bb083cbaa05ce4 (commit)
   via  67b6f5784ae8d2e5c5b783b24a4b0ff555a28d44 (commit)
  from  cc74f213248f910c1c7908b23be07485752e85b9 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 3854b5e6146ff8efeb4379a502bb083cbaa05ce4
Author: Andrew Tridgell 
Date:   Wed Aug 5 20:23:12 2009 +1000

changed BCC handling for SMBwriteX to handle broken MacOSX client

see bug #6610

The MacOSX SMB client sets the BCC value in SMBwriteX calls to zero
instead of the correct size. Checking against WindowsXP, I've found
that Windows uses the maximum of the computed buffer size and the
given BCC value. I've changed Samba4 to do the same to allow MacOSX to
work.

I've limited this change to non-chained packets to ensure we don't get
the possibility of exploits based on overlapping chained requests

commit 67b6f5784ae8d2e5c5b783b24a4b0ff555a28d44
Author: Andrew Tridgell 
Date:   Wed Aug 5 20:19:36 2009 +1000

on buffer overflow windows gives SMBSRV:ERRerror here

---

Summary of changes:
 source4/smb_server/smb/receive.c |   21 -
 source4/smb_server/smb/reply.c   |2 +-
 2 files changed, 9 insertions(+), 14 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source4/smb_server/smb/receive.c b/source4/smb_server/smb/receive.c
index 03631f8..9a03909 100644
--- a/source4/smb_server/smb/receive.c
+++ b/source4/smb_server/smb/receive.c
@@ -407,19 +407,14 @@ NTSTATUS smbsrv_recv_smb_request(void *private_data, 
DATA_BLOB blob)
req->in.data = req->in.vwv + VWV(req->in.wct) + 2;
req->in.data_size = SVAL(req->in.vwv, VWV(req->in.wct));
 
-   /* the bcc length is only 16 bits, but some packets
-  (such as SMBwriteX) can be much larger than 64k. We
-  detect this by looking for a large non-chained NBT
-  packet (at least 64k bigger than what is
-  specified). If it is detected then the NBT size is
-  used instead of the bcc size */
-   if (req->in.data_size + 0x1 <= 
-   req->in.size - PTR_DIFF(req->in.data, req->in.buffer) &&
-   ( message_flags(command) & LARGE_REQUEST) &&
-   ( !(message_flags(command) & AND_X) ||
- (req->in.wct < 1 || SVAL(req->in.vwv, VWV(0)) == 
SMB_CHAIN_NONE) )
-   ) {
-   /* its an oversized packet! fun for all the family */
+   /* special handling for oversize calls. Windows seems
+  to take the maximum of the BCC value and the
+  computed buffer size. This handles oversized writeX
+  calls, and possibly oversized SMBtrans calls */
+   if ((message_flags(command) & LARGE_REQUEST) &&
+   ( !(message_flags(command) & AND_X) ||
+ (req->in.wct < 1 || SVAL(req->in.vwv, VWV(0)) == 
SMB_CHAIN_NONE)) &&
+   req->in.data_size < req->in.size - 
PTR_DIFF(req->in.data,req->in.buffer)) {
req->in.data_size = req->in.size - 
PTR_DIFF(req->in.data,req->in.buffer);
}
}
diff --git a/source4/smb_server/smb/reply.c b/source4/smb_server/smb/reply.c
index 0433d35..104caca 100644
--- a/source4/smb_server/smb/reply.c
+++ b/source4/smb_server/smb/reply.c
@@ -1063,7 +1063,7 @@ void smbsrv_reply_write_and_X(struct smbsrv_request *req)
 
/* make sure the data is in bounds */
if (req_data_oob(&req->in.bufinfo, io->writex.in.data, 
io->writex.in.count)) {
-   smbsrv_send_error(req, NT_STATUS_FOOBAR);
+   smbsrv_send_error(req, NT_STATUS_DOS(ERRSRV, ERRerror));
return;
}
 


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch v3-4-test updated - release-4-0-0alpha7-1201-g5c6aa5c

2009-08-05 Thread Karolin Seeger
The branch, v3-4-test has been updated
   via  5c6aa5ce9fb0cc5d63d04b0777d296c82e61c0a5 (commit)
  from  e7e1a6b3237550ef90db6a52a023885f616f722b (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-4-test


- Log -
commit 5c6aa5ce9fb0cc5d63d04b0777d296c82e61c0a5
Author: Volker Lendecke 
Date:   Mon Jul 27 14:47:41 2009 +0200

Fix a valgrind error in chain_reply

construct_reply() references the request after chain_reply has freed it.
(cherry picked from commit 5135ebd6f099518f0a0b5796e8057210be824740)

Addresses bug #6611.

---

Summary of changes:
 source3/include/smb.h  |2 ++
 source3/smbd/process.c |   13 ++---
 2 files changed, 12 insertions(+), 3 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/include/smb.h b/source3/include/smb.h
index 9cae327..b20a8ef 100644
--- a/source3/include/smb.h
+++ b/source3/include/smb.h
@@ -659,6 +659,8 @@ struct smb_request {
 * state information for async smb handling
 */
void *async_priv;
+
+   bool done;
 };
 
 /* Defines for the sent_oplock_break field above. */
diff --git a/source3/smbd/process.c b/source3/smbd/process.c
index 962b492..e1069eb 100644
--- a/source3/smbd/process.c
+++ b/source3/smbd/process.c
@@ -377,6 +377,7 @@ void init_smb_request(struct smb_request *req,
req->conn = conn_find(req->tid);
req->chain_fsp = NULL;
req->chain_outbuf = NULL;
+   req->done = false;
smb_init_perfcount_data(&req->pcd);
 
/* Ensure we have at least wct words and 2 bytes of bcc. */
@@ -1395,6 +1396,11 @@ static void construct_reply(char *inbuf, int size, 
size_t unread_bytes,
req->unread_bytes = 0;
}
 
+   if (req->done) {
+   TALLOC_FREE(req);
+   return;
+   }
+
if (req->outbuf == NULL) {
return;
}
@@ -1650,8 +1656,8 @@ void chain_reply(struct smb_request *req)
exit_server_cleanly("chain_reply: srv_send_smb "
"failed.");
}
-   TALLOC_FREE(req);
-
+   TALLOC_FREE(req->chain_outbuf);
+   req->done = true;
return;
}
 
@@ -1772,7 +1778,8 @@ void chain_reply(struct smb_request *req)
  &req->pcd)) {
exit_server_cleanly("construct_reply: srv_send_smb failed.");
}
-   TALLOC_FREE(req);
+   TALLOC_FREE(req->chain_outbuf);
+   req->done = true;
 }
 
 /


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch v3-4-test updated - release-4-0-0alpha7-1200-ge7e1a6b

2009-08-05 Thread Karolin Seeger
The branch, v3-4-test has been updated
   via  e7e1a6b3237550ef90db6a52a023885f616f722b (commit)
  from  1a8294f1dc7953bd7f45e9b65fe6b5ec005634d0 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-4-test


- Log -
commit e7e1a6b3237550ef90db6a52a023885f616f722b
Author: Günther Deschner 
Date:   Mon Aug 3 23:41:08 2009 +0200

s3-spoolss: fix crash bug in spoolss_addprinterex_level_2.

Fixes bug #6607.

Guenther
(cherry picked from commit 75030ff2b16a3ddb79367d970590da2375f7e3dc)

---

Summary of changes:
 source3/rpc_server/srv_spoolss_nt.c |2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/rpc_server/srv_spoolss_nt.c 
b/source3/rpc_server/srv_spoolss_nt.c
index 8170680..87735d3 100644
--- a/source3/rpc_server/srv_spoolss_nt.c
+++ b/source3/rpc_server/srv_spoolss_nt.c
@@ -7530,7 +7530,7 @@ static WERROR spoolss_addprinterex_level_2(pipes_struct 
*p,
}
 
/* you must be a printer admin to add a new printer */
-   if (!print_access_check(NULL, snum, PRINTER_ACCESS_ADMINISTER)) {
+   if (!print_access_check(p->server_info, snum, 
PRINTER_ACCESS_ADMINISTER)) {
free_a_printer(&printer,2);
return WERR_ACCESS_DENIED;
}


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch v3-4-test updated - release-4-0-0alpha7-1199-g1a8294f

2009-08-05 Thread Karolin Seeger
The branch, v3-4-test has been updated
   via  1a8294f1dc7953bd7f45e9b65fe6b5ec005634d0 (commit)
  from  ffb6b4e6f7e47e8f22519d616e4e31444e417d16 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-4-test


- Log -
commit 1a8294f1dc7953bd7f45e9b65fe6b5ec005634d0
Author: Stefan Metzmacher 
Date:   Mon Jul 13 13:24:19 2009 +0200

s3:net: Fix Bug #6222. Default to DRSUAPI replication for net rpc vampire 
keytab

metze

Signed-off-by: Günther Deschner 
(cherry picked from commit 8646b9521d267284a335aafba3df6039c41b8370)

---

Summary of changes:
 source3/utils/net_rpc_samsync.c |   11 +++
 1 files changed, 7 insertions(+), 4 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/utils/net_rpc_samsync.c b/source3/utils/net_rpc_samsync.c
index 6b23db7..309be17 100644
--- a/source3/utils/net_rpc_samsync.c
+++ b/source3/utils/net_rpc_samsync.c
@@ -493,17 +493,20 @@ int rpc_vampire_keytab(struct net_context *c, int argc, 
const char **argv)
 
if (!dc_info.is_ad) {
printf("DC is not running Active Directory\n");
-   return -1;
-   }
-
-   if (dc_info.is_mixed_mode) {
ret = run_rpc_command(c, cli, &ndr_table_netlogon.syntax_id,
  0,
  rpc_vampire_keytab_internals, argc, argv);
+   return -1;
} else {
ret = run_rpc_command(c, cli, &ndr_table_drsuapi.syntax_id,
  NET_FLAGS_SEAL,
  rpc_vampire_keytab_ds_internals, argc, 
argv);
+   if (ret != 0 && dc_info.is_mixed_mode) {
+   printf("Fallback to NT4 vampire on Mixed-Mode AD 
Domain\n");
+   ret = run_rpc_command(c, cli, 
&ndr_table_netlogon.syntax_id,
+ 0,
+ rpc_vampire_keytab_internals, 
argc, argv);
+   }
}
 
return ret;


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch v3-4-test updated - release-4-0-0alpha7-1198-gffb6b4e

2009-08-05 Thread Karolin Seeger
The branch, v3-4-test has been updated
   via  ffb6b4e6f7e47e8f22519d616e4e31444e417d16 (commit)
  from  2666b3e27444ffcad3afc21e276f189ac238433f (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=v3-4-test


- Log -
commit ffb6b4e6f7e47e8f22519d616e4e31444e417d16
Author: Günther Deschner 
Date:   Tue Aug 4 12:21:49 2009 +0200

s3-spoolss: Fix Bug #6568: _spoolss_GetPrintProcessorDirectory() 
implementation.

We should always return a local path so that users are not forced to setup a
[prnproc$] share on the server. This restores pre-3.4.0 spoolss behaviour.

Guenther
(cherry picked from commit 74454cc731f202361f1dce47fa850810bfeb36c8)

---

Summary of changes:
 source3/rpc_server/srv_spoolss_nt.c |6 +-
 1 files changed, 5 insertions(+), 1 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source3/rpc_server/srv_spoolss_nt.c 
b/source3/rpc_server/srv_spoolss_nt.c
index 855aa30..8170680 100644
--- a/source3/rpc_server/srv_spoolss_nt.c
+++ b/source3/rpc_server/srv_spoolss_nt.c
@@ -9598,8 +9598,12 @@ WERROR _spoolss_GetPrintProcessorDirectory(pipes_struct 
*p,
 
/* r->in.level is ignored */
 
+   /* We always should reply with a local print processor directory so that
+* users are not forced to have a [prnproc$] share on the Samba spoolss
+* server - Guenther */
+
result = getprintprocessordirectory_level_1(p->mem_ctx,
-   r->in.server,
+   NULL, /* r->in.server */
r->in.environment,
&r->out.info->info1);
if (!W_ERROR_IS_OK(result)) {


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha8-841-gcc74f21

2009-08-05 Thread Matthias Dieter Wallnöfer
The branch, master has been updated
   via  cc74f213248f910c1c7908b23be07485752e85b9 (commit)
  from  996a2054fb951139344712ee68774a55fb65ae1e (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit cc74f213248f910c1c7908b23be07485752e85b9
Author: Matthias Dieter Wallnöfer 
Date:   Wed Aug 5 10:48:25 2009 +0200

s4:torture The test logic for the target was wrong. This should correct it.

---

Summary of changes:
 source4/torture/ldap/basic.c |8 
 1 files changed, 4 insertions(+), 4 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source4/torture/ldap/basic.c b/source4/torture/ldap/basic.c
index ff95ba7..c2a26f8 100644
--- a/source4/torture/ldap/basic.c
+++ b/source4/torture/ldap/basic.c
@@ -217,7 +217,7 @@ static bool test_error_codes(struct torture_context *tctx,
WERROR err;
NTSTATUS status;
 
-   printf("Testing error codes\n");
+   printf("Testing error codes - to make this test pass against SAMBA 4 
you have to specify the target!\n");
 
if (!basedn) {
return false;
@@ -257,7 +257,7 @@ static bool test_error_codes(struct torture_context *tctx,
err = ad_error(rep->r.AddResponse.errormessage, &endptr);
err_code_str = win_errstr(err);
printf(" - Errorcode: %s; Reason: %s\n", err_code_str, endptr);
-   if (torture_setting_bool(tctx, "samba4", false)) {
+   if (!torture_setting_bool(tctx, "samba4", false)) {
if ((!W_ERROR_EQUAL(err, WERR_DS_REFERRAL))
|| (rep->r.AddResponse.resultcode != 10)) {
return false;
@@ -298,7 +298,7 @@ static bool test_error_codes(struct torture_context *tctx,
err = ad_error(rep->r.ModifyResponse.errormessage, &endptr);
err_code_str = win_errstr(err);
printf(" - Errorcode: %s; Reason: %s\n", err_code_str, endptr);
-   if (torture_setting_bool(tctx, "samba4", false)) {
+   if (!torture_setting_bool(tctx, "samba4", false)) {
if ((!W_ERROR_EQUAL(err, WERR_INVALID_PARAM))
|| (rep->r.ModifyResponse.resultcode != 53)) {
return false;
@@ -337,7 +337,7 @@ static bool test_error_codes(struct torture_context *tctx,
err = ad_error(rep->r.DelResponse.errormessage, &endptr);
err_code_str = win_errstr(err);
printf(" - Errorcode: %s; Reason: %s\n", err_code_str, endptr);
-   if (torture_setting_bool(tctx, "samba4", false)) {
+   if (!torture_setting_bool(tctx, "samba4", false)) {
if ((!W_ERROR_EQUAL(err, WERR_DS_OBJ_NOT_FOUND))
|| (rep->r.DelResponse.resultcode != 32)) {
return false;


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha8-840-g996a205

2009-08-05 Thread Stefan Metzmacher
The branch, master has been updated
   via  996a2054fb951139344712ee68774a55fb65ae1e (commit)
  from  f22408913846b2510352c60e6476b2a693e1a7ee (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 996a2054fb951139344712ee68774a55fb65ae1e
Author: Stefan Metzmacher 
Date:   Tue Aug 4 13:43:29 2009 +0200

s4:heimdal_build: define HEIMDAL_LOCALEDIR

metze

---

Summary of changes:
 source4/heimdal_build/roken.h |1 +
 1 files changed, 1 insertions(+), 0 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source4/heimdal_build/roken.h b/source4/heimdal_build/roken.h
index 87060cf..ea9103e 100644
--- a/source4/heimdal_build/roken.h
+++ b/source4/heimdal_build/roken.h
@@ -10,6 +10,7 @@
 /* HDB module dir - set to Samba LIBDIR/hdb ? */
 #define HDBDIR "/usr/heimdal/lib"
 #define LIBDIR "/usr/heimdal/lib"
+#define HEIMDAL_LOCALEDIR "/usr/heimdal/locale"
 
 /* Maximum values on all known systems */
 #define MaxHostNameLen (64+4)


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha8-839-gf224089

2009-08-05 Thread Stefan Metzmacher
The branch, master has been updated
   via  f22408913846b2510352c60e6476b2a693e1a7ee (commit)
  from  e2ed5029e97671b307af06c9fff1d4f0442553a2 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit f22408913846b2510352c60e6476b2a693e1a7ee
Author: Stefan Metzmacher 
Date:   Wed Aug 5 10:05:56 2009 +0200

s4:ldap_server: make sure we shutdown the tls socket before 
stream_terminate_connection() removes the fd event

This fixes a crash bug where tls_destructor() relies on the fd event still 
being there.

metze

---

Summary of changes:
 source4/ldap_server/ldap_server.c |1 +
 1 files changed, 1 insertions(+), 0 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source4/ldap_server/ldap_server.c 
b/source4/ldap_server/ldap_server.c
index 72431e9..b119620 100644
--- a/source4/ldap_server/ldap_server.c
+++ b/source4/ldap_server/ldap_server.c
@@ -51,6 +51,7 @@ void ldapsrv_terminate_connection(struct ldapsrv_connection 
*conn,
 {
packet_recv_disable(conn->packet);
TALLOC_FREE(conn->packet);
+   TALLOC_FREE(conn->sockets.tls);
stream_terminate_connection(conn->connection, reason);
 }
 


-- 
Samba Shared Repository


svn commit: samba-web r1315 - in trunk: . devel history

2009-08-05 Thread kseeger
Author: kseeger
Date: 2009-08-05 02:00:01 -0600 (Wed, 05 Aug 2009)
New Revision: 1315

WebSVN: 
http://websvn.samba.org/cgi-bin/viewcvs.cgi?view=rev&root=samba-web&rev=1315

Log:
Announce Samba 3.0.36
Karolin
Added:
   trunk/history/samba-3.0.36.html
Modified:
   trunk/devel/index.html
   trunk/header_columns.html
   trunk/history/header_history.html
   trunk/index.html


Changeset:
Modified: trunk/devel/index.html
===
--- trunk/devel/index.html  2009-07-29 08:35:44 UTC (rev 1314)
+++ trunk/devel/index.html  2009-08-05 08:00:01 UTC (rev 1315)
@@ -59,16 +59,6 @@
   This is the new combined branch for 3.x.x and 4.x.x 
development.
 
 
-  v3-0-test
-  This is the current branch for 3.0.x maintenance
- (security fixes only).
-
-
-  v3-0-stable
-  This is the current branch for 3.0.x maintenance releases
- (security fixes only).
-
-
   v3-2-test
   This is the current branch for 3.2.x maintenance
  (security fixes only).

Modified: trunk/header_columns.html
===
--- trunk/header_columns.html   2009-07-29 08:35:44 UTC (rev 1314)
+++ trunk/header_columns.html   2009-08-05 08:00:01 UTC (rev 1315)
@@ -144,9 +144,9 @@
 Samba 3.2.13 
(gzipped)
 Release Notes 
3.2.13
 Signature 
3.2.13
-Samba 3.0.35 
(gzipped)
-Release Notes 
3.0.35
-Signature 
3.0.35
+Samba 3.0.36 
(gzipped)
+Release Notes 
3.0.36
+Signature 
3.0.36
 

 Maintenance

Modified: trunk/history/header_history.html
===
--- trunk/history/header_history.html   2009-07-29 08:35:44 UTC (rev 1314)
+++ trunk/history/header_history.html   2009-08-05 08:00:01 UTC (rev 1315)
@@ -100,6 +100,7 @@
 samba-3.2.2
 samba-3.2.1
 samba-3.2.0
+samba-3.0.36
 samba-3.0.35
 samba-3.0.34
 samba-3.0.33

Added: trunk/history/samba-3.0.36.html
===
--- trunk/history/samba-3.0.36.html (rev 0)
+++ trunk/history/samba-3.0.36.html 2009-08-05 08:00:01 UTC (rev 1315)
@@ -0,0 +1,106 @@
+http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd";>
+http://www.w3.org/1999/xhtml";>
+
+
+Samba - Release Notes Archive
+
+
+
+
+   Samba 3.0.36 Available for Download
+
+
+
+   ==
+   Release Notes for Samba 3.0.36
+   August, 5 2009
+   ==
+
+
+This is the latest bugfix release of the Samba 3.0 series.
+
+Please note, that the 3.0 series will be DISCONTINUED after this release!
+There will be neither any bugfix release nor any security release. Updating
+to the latest release series is strongly recommended. For more information
+on current Samba releases, please see
+
+http://wiki.samba.org/index.php/Samba3_Release_Planning
+
+
+Major enhancements included in Samba 3.0.36 are:
+
+   o Fix Winbind crash on 'getent group' (bug #5906).
+   o Excel save operation corrupts file ACLs (bug #4308).
+   o Prevent segmentation fault on joining a very long domain name.
+
+
+##
+Changes
+###
+
+Changes since 3.0.35
+
+
+
+o   Michael Adam 
+* BUG 5906: Fix Winbind crash on 'getent group'.
+* BUG 6066: netinet/ip.h present but cannot be compiled on Solaris.
+
+
+o   Jeremy Allison 
+* BUG 4308: Excel save operation corrupts file ACLs.
+* BUG 6099: In order to allow Win7 to connect to a Samba NT style
+* BUG 6279: Fix Winbind crash.
+  PDC we set the flags before we know if it's an error or not.
+* Fix logic error in try_chown.
+* Correctly use chroot().
+* Fix bug in processing of open modes in POSIX open.
+
+
+o   Günther Deschner 
+* Don't install the cifs.upcall binary twice.
+
+
+o   Steve French 
+* BUG 4640: Fix guest mounts in mount-cifs.
+* Fix mount.cifs handling of -V option.
+
+
+o   Bhaskar Jain (bhajain) 
+* Prevent segmentation fault on joining a very long domain name.
+
+
+o   Günter Kukkukk 
+* Don't try and delete a default ACL from a file.
+
+
+o   Volker Lendecke 
+* Add workaround for MS KB932762.
+
+
+o   Shirish Pargaonkar 
+* BUG 4370: Clean-up entries in /etc/mtab after unmount.
+* Add fakemount (-f) and nomtab (-n) flags to mount.cifs.
+
+
+o   Ted Percival 
+* Fix a crash during name resolution when log level >= 10
+  and libc segfaults if printf is passed NULL for a "%s" arg
+ (eg. Solaris).
+
+
+o   Miguel Suarez 
+* BUG 6085: Fix build of vfs_

[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha8-838-ge2ed502

2009-08-05 Thread mdw
The branch, master has been updated
   via  e2ed5029e97671b307af06c9fff1d4f0442553a2 (commit)
  from  00a8ff5fe9acf965395b99b39b0c24a5517b6e2b (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit e2ed5029e97671b307af06c9fff1d4f0442553a2
Author: Matthias Dieter Wallnöfer 
Date:   Wed Aug 5 09:48:45 2009 +0200

s4:torture Remove some unwanted code in the LDAP test - hope this fixes up 
the test failures

---

Summary of changes:
 source4/torture/ldap/basic.c |   12 
 1 files changed, 0 insertions(+), 12 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source4/torture/ldap/basic.c b/source4/torture/ldap/basic.c
index 3ed0b48..ff95ba7 100644
--- a/source4/torture/ldap/basic.c
+++ b/source4/torture/ldap/basic.c
@@ -269,18 +269,6 @@ static bool test_error_codes(struct torture_context *tctx,
}
}
 
-   printf(" Try a wrong removal\n");
-
-   msg->type = LDAP_TAG_DelRequest;
-   msg->r.DelRequest.dn = "";
-
-   req = ldap_request_send(conn, msg);
-   if (!req) {
-   return false;
-   }
-
-   status = ldap_result_one(req, &rep, LDAP_TAG_DelResponse);
-
printf(" Try a wrong modification\n");
 
msg->type = LDAP_TAG_ModifyRequest;


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha8-837-g00a8ff5

2009-08-05 Thread Andrew Tridgell
The branch, master has been updated
   via  00a8ff5fe9acf965395b99b39b0c24a5517b6e2b (commit)
  from  0a16265bc21e6f1f8cef4f38b7b45f3fd356527c (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 00a8ff5fe9acf965395b99b39b0c24a5517b6e2b
Author: Andrew Tridgell 
Date:   Wed Aug 5 17:51:21 2009 +1000

fixed a problem with group policy writes causing policy corruption

This bug was caused by two things:

  1) in the unix ACL mapping, we were not taking into account group
  write permssions for the SEC_STD_DELETE flag

  2) when a file is created using OVERWRITE mode, a fchmod() would
  fail if the user is not the file owner. We resolve that by only
  doing the fchmod() if the mapped file attribute does not match the
  desired file attribute

---

Summary of changes:
 source4/ntvfs/posix/pvfs_acl.c  |   37 +
 source4/ntvfs/posix/pvfs_open.c |   10 +++---
 source4/ntvfs/posix/pvfs_util.c |5 -
 3 files changed, 48 insertions(+), 4 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source4/ntvfs/posix/pvfs_acl.c b/source4/ntvfs/posix/pvfs_acl.c
index 203b6b1..ad7ac5a 100644
--- a/source4/ntvfs/posix/pvfs_acl.c
+++ b/source4/ntvfs/posix/pvfs_acl.c
@@ -449,6 +449,35 @@ static bool pvfs_read_only(struct pvfs_state *pvfs, 
uint32_t access_mask)
 }
 
 /*
+  see if we are a member of the appropriate unix group
+ */
+static bool pvfs_group_member(struct pvfs_state *pvfs, gid_t gid)
+{
+   int i, ngroups;
+   gid_t *groups;
+   if (getegid() == gid) {
+   return true;
+   }
+   ngroups = getgroups(0, NULL);
+   if (ngroups == 0) {
+   return false;
+   }
+   groups = talloc_array(pvfs, gid_t, ngroups);
+   if (groups == NULL) {
+   return false;
+   }
+   if (getgroups(ngroups, groups) != ngroups) {
+   talloc_free(groups);
+   return false;
+   }
+   for (i=0; ist.st_mode & S_IWOTH) ||
+   ((name->st.st_mode & S_IWGRP) && 
+pvfs_group_member(pvfs, name->st.st_gid))) {
+   max_bits |= SEC_STD_ALL;
+   }
+
if (uwrap_enabled()) {
/* when running with the uid wrapper, files will be created
   owned by the ruid, but we may have a different simulated 
@@ -491,6 +526,8 @@ NTSTATUS pvfs_access_check_unix(struct pvfs_state *pvfs,
}
 
if (*access_mask & ~max_bits) {
+   DEBUG(0,(__location__ " denied access to '%s' - wanted 0x%08x 
but got 0x%08x (missing 0x%08x)\n",
+name->full_name, *access_mask, max_bits, *access_mask 
& ~max_bits));
return NT_STATUS_ACCESS_DENIED;
}
 
diff --git a/source4/ntvfs/posix/pvfs_open.c b/source4/ntvfs/posix/pvfs_open.c
index 12f50fc..46e39a0 100644
--- a/source4/ntvfs/posix/pvfs_open.c
+++ b/source4/ntvfs/posix/pvfs_open.c
@@ -534,7 +534,7 @@ static int pvfs_handle_destructor(struct pvfs_file_handle 
*h)
 
if (!timeval_is_zero(&tv[0]) || !timeval_is_zero(&tv[1])) {
if (utimes(h->name->full_name, tv) == -1) {
-   DEBUG(0,("pvfs_handle_destructor: utimes() 
failed '%s' - %s\n",
+   DEBUG(3,("pvfs_handle_destructor: utimes() 
failed '%s' - %s\n",
 h->name->full_name, strerror(errno)));
}
}
@@ -1516,6 +1516,8 @@ NTSTATUS pvfs_open(struct ntvfs_module_context *ntvfs,
if (fd == -1) {
status = pvfs_map_errno(f->pvfs, errno);
 
+   DEBUG(0,(__location__ " mapped errno %s for %s (was %d)\n", 
+nt_errstr(status), f->handle->name->full_name, errno));
/*
 * STATUS_MORE_ENTRIES is EAGAIN or EWOULDBLOCK
 */
@@ -1581,10 +1583,12 @@ NTSTATUS pvfs_open(struct ntvfs_module_context *ntvfs,
if (f->handle->name->stream_id == 0 &&
(io->generic.in.open_disposition == NTCREATEX_DISP_OVERWRITE ||
 io->generic.in.open_disposition == NTCREATEX_DISP_OVERWRITE_IF)) {
-   /* for overwrite we need to replace file permissions */
+   /* for overwrite we may need to replace file permissions */
uint32_t attrib = io->ntcreatex.in.file_attr | 
FILE_ATTRIBUTE_ARCHIVE;
mode_t mode = pvfs_fileperms(pvfs, attrib);
-   if (fchmod(fd, mode) == -1) {
+   if (f->handle->name->st.st_mode != mode &&
+   f->handle->name->dos.attrib != attrib &&
+   fchmod(fd, mode) == -1) {
talloc_free(lck);
return pvfs_map_errno(pvfs, errno);
}
-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha8-844-g39b0158

2009-08-05 Thread Matthias Dieter Wallnöfer
The branch, master has been updated
   via  39b015837378b6dca72c477225444e700fe40040 (commit)
  from  3854b5e6146ff8efeb4379a502bb083cbaa05ce4 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 39b015837378b6dca72c477225444e700fe40040
Author: Matthias Dieter Wallnöfer 
Date:   Wed Aug 5 20:28:05 2009 +0200

s4:ldb Cosmetic corrections in "rdn_name" module

---

Summary of changes:
 source4/lib/ldb/modules/rdn_name.c |8 
 1 files changed, 4 insertions(+), 4 deletions(-)


Changeset truncated at 500 lines:

diff --git a/source4/lib/ldb/modules/rdn_name.c 
b/source4/lib/ldb/modules/rdn_name.c
index e9f873f..65cdb25 100644
--- a/source4/lib/ldb/modules/rdn_name.c
+++ b/source4/lib/ldb/modules/rdn_name.c
@@ -1,8 +1,8 @@
 /* 
ldb database library
 
-   Copyright (C) Andrew Bartlet 2005
-   Copyright (C) Simo Sorce 2006-2008
+   Copyright (C) Andrew Bartlett 2005
+   Copyright (C) Simo Sorce 2006-2008
 
  ** NOTE! The following LGPL license applies to the ldb
  ** library. This does NOT imply that all of Samba is released
@@ -23,13 +23,13 @@
 */
 
 /*
- *  Name: rdb_name
+ *  Name: rdn_name
  *
  *  Component: ldb rdn name module
  *
  *  Description: keep a consistent name attribute on objects manpulations
  *
  *  Author: Andrew Bartlet
  *
  *  Modifications:
  *- made the module async
@@ -23,13 +23,13 @@
  *  Description: keep a consistent name attribute on objects manpulations
  *
- *  Author: Andrew Bartlet
+ *  Author: Andrew Bartlett
  *
  *  Modifications:


diff -

[SCM] Samba Shared Repository - annotated tag release-3-0-36 created - release-3-0-36

2009-08-05 Thread Karolin Seeger
The annotated tag, release-3-0-36 has been created
at  61b3dee53f076ef7da6596f5a9d3efd6a1911fec (tag)
   tagging  9fae819cd93e56d68facc51586c5fb3bd228a5bc (commit)
  replaces  release-3-0-35
 tagged by  Karolin Seeger
on  Wed Aug 5 09:24:09 2009 +0200

- Log -
tag release-3-0-36
-BEGIN PGP SIGNATURE-
Version: GnuPG v2.0.9 (GNU/Linux)

iD8DBQBKeTOzbzORW2Vot+oRAjICAJ9I8gZJTl9pgLv0KFHLG5Eqw1fjNQCfXaEA
UtTFlkZGb+ITNoMbJfrx8H8=
=WVLQ
-END PGP SIGNATURE-

Andreas Schneider (1):
  Document default of the printing config variable.

Bhaskar Jain (bhajain) (1):
  prevent segmentation fault on joining a very long domain name in 
samba-3.0.32

Björn Jacke (1):
  prefer gssapi header files from subdirectory

Günter Kukkukk (1):
  Don't try and delete a default ACL from a file.

Günther Deschner (2):
  build: don't install the cifs.upcall binary twice.
  s3-examples: Fix Bug #6205. Correct sample smb.conf share configuration.

Jelmer Vernooij (4):
  Make the make output a bit less chatty.
  Add test target in Makefile.
  Use double colon targets.
  Depend on latexfigures files directly as using a rule in between causes 
problems.

Jeremy Allison (12):
  Another attempt to fix bug #4308 - Excel save operation corrupts file 
ACLs.
  Second part of the attemt to fix #4308 - Excel save operation corrupts 
file ACLs.
  Fix logic error in try_chown - we shouldn't arbitrarily chown
  Apply same logic fix for #4308 Excel save operation corrupts file ACLs
  Fix bug #5906 - Winbindd crash on 'getent group' (INTERNAL ERROR: Signal 
11).
  Noted by Vericode analysis. Correctly use chroot().
  Attempt to fix bug #6099. According to Microsoft
  Fix bug in processing of open modes in POSIX open.
  Now we're allowing a lower bound for auth_len, ensure we
  Get the sense of the integer wrap test the right way around. Sorry.
  Fix bug #6279 - winbindd crash. Cope with LDAP libraries returning 
LDAP_SUCCESS but not returning a result.
  Add comment explaining the previous fix. (and fix the previous patch :-).

Karolin Seeger (12):
  build_docs: Use 'make distclean' instead of 'make clean'.
  docs: Fix formatting issue in man libsmbclient.
  docs: Describe "service" in man mount.cifs.
  s3/docs: Fix typo in man mount.cifs.
  s3/docs: Fix serveral typos.
  s3/docs: Fix typo.
  s3/docs: Fix typos.
  s3/docs: Fix typo.
  s3/docs: Correct version number.
  VERSION: Raise version number up to 3.0.36.
  WHATSNEW: Start WHATSNEW for 3.0.36.
  Makefile.in: Fix installation of cifs.upcall.

Lars Müller (2):
  Conditional install of the cifs.upcall man page
  Adjust regex to match variable names including underscores

Michael Adam (9):
  s3:docs: fix distclean target and add realdistclean target
  s3:create-tarball: also include the VENDOR_PATCH in the version
  s3:docs: fix ommission in fix of (real)distclean targets
  s3:docs: clean generated .png images in "make clean"
  s3:docs: clean build/catalog.xml in "make clean"
  build-docs: cleanup exit of the script
  libreplace: fix bug #6066 - netinet/ip.h present but cannot be compiled
  libreplace: fix detection of netinet/ip.h on solaris 8
  docs: fix two typos in the mount.cifs manpage

Miguel Suarez (1):
  Fix bug #6085 - In vfs_default.c change utime( ) call.

Shirish Pargaonkar (2):
  umount.cifs: clean-up entries in /etc/mtab after unmount
  mount.cifs: add fakemount (-f) and nomtab (-n) flags to mount.cifs

Steve French (2):
  Fix mount.cifs handling of -V option (to display version)
  Fix guest mounts

Ted Percival (1):
  Probably fixes a crash during name resolution when log level >= 10

Volker Lendecke (2):
  Complete the fix for bug 6100
  Workaround for KB932762

Yasuma Takeda (1):
  Fix bug #6098 - When the DNS server is invalid, the ads_find_dc() does 
not work correctly with "security = domain"

---


-- 
Samba Shared Repository


[SCM] Samba Shared Repository - branch master updated - release-4-0-0alpha8-836-g0a16265

2009-08-05 Thread Volker Lendecke
The branch, master has been updated
   via  0a16265bc21e6f1f8cef4f38b7b45f3fd356527c (commit)
   via  01ea26bf28ab697af03c7ebc3a1261c240fe1360 (commit)
   via  fec380818ffdd7fba58e8dd591049c4b2428ab7d (commit)
   via  1dc1ac00512a28bdc025b00fbfa676b0f5b15751 (commit)
   via  718a26fd29036cc200cdc1c320733eafe84d2337 (commit)
   via  592822786d0a26bdf283ca4621c0df6f7f671869 (commit)
   via  ce42ea3ab8c69a3f650d4c9bc787e4805aad928d (commit)
   via  f09a95aaff4542df4225f3828a0d737497f0f2e8 (commit)
   via  ff3ce9016a43906df55a0922f0697c91d255de88 (commit)
   via  bd9d7f75e352985f1b0e0785f0ba94dea19d2601 (commit)
   via  5bbb7a0d143b34b6a2a2c4adb1114120cddd74bf (commit)
   via  9dc401a20ec608d4d8ae25fb4e81c462e9ced415 (commit)
   via  afc82444fd367e8b8541e4a41a86966a288ed2ef (commit)
   via  0418d38bc80dc8680834875629a3df8e1734b885 (commit)
   via  7077492778dbda30e5f865ae1d0ab0237e00f54f (commit)
   via  360227a0feb443fbbcc420295d5666da5823685a (commit)
   via  10685b37d4dc16dc75c48c08937f003af4968a0c (commit)
   via  292f3f896fa5bc381c88526fc73a6224b8d286f0 (commit)
   via  9b369ffcf0f113871b00de4229432a74fe436834 (commit)
   via  3eff8e93e283828afdb3413aec2dae5c01b101b3 (commit)
   via  5db561a608a11895d8a9a038a98a9fcc7c867d59 (commit)
   via  153ae58d7d37daffc7c5547ef9174baf64f9aaa7 (commit)
   via  fb7150f23b154fe53a91f3433ea33cf680d4fa93 (commit)
   via  ea286fed7adf93311b0ca14c3ff1e7bac74a0b9b (commit)
   via  9c6f4cd12a3e62165782e34226888648649a0fef (commit)
   via  a5416770776c0ade8518e8875d47097662b026a6 (commit)
   via  f6554611ab90aa113a7579ce3a9fef765c19d98c (commit)
   via  74b45ba46cbf58c1bf9ef89f5f88509065cd81d2 (commit)
   via  fa59f9720d56ffaf07c13376118c452a4162f3df (commit)
   via  bb359c780aee3fd7e1074db93a28c95590ae5d36 (commit)
   via  2d6589fb0243cb2b73615de1aaea38a3059c08ed (commit)
   via  6cf3db91499ebd245b08997a319edf36cfee3365 (commit)
  from  ddd13c6816e7d289406948fe2f68db1aba7669d3 (commit)

http://gitweb.samba.org/?p=samba.git;a=shortlog;h=master


- Log -
commit 0a16265bc21e6f1f8cef4f38b7b45f3fd356527c
Author: Volker Lendecke 
Date:   Tue Aug 4 16:26:07 2009 -0400

s3:winbind: Convert WINBINDD_GETGROUPS to the new API

commit 01ea26bf28ab697af03c7ebc3a1261c240fe1360
Author: Volker Lendecke 
Date:   Tue Aug 4 16:22:42 2009 -0400

s3:winbind: Add async wb_gettoken

commit fec380818ffdd7fba58e8dd591049c4b2428ab7d
Author: Volker Lendecke 
Date:   Tue Aug 4 16:20:18 2009 -0400

s3:winbind: Convert WINBINDD_GETUSERDOMGROUPS to the new API

commit 1dc1ac00512a28bdc025b00fbfa676b0f5b15751
Author: Volker Lendecke 
Date:   Tue Aug 4 16:07:01 2009 -0400

s3:winbind: Add async wb_lookupusergroups

commit 718a26fd29036cc200cdc1c320733eafe84d2337
Author: Volker Lendecke 
Date:   Sun Aug 2 18:01:54 2009 +0200

s3:winbind: Make wcache_lookup_usergroups externally visible

commit 592822786d0a26bdf283ca4621c0df6f7f671869
Author: Volker Lendecke 
Date:   Tue Aug 4 15:58:45 2009 -0400

s3:winbind: Convert WINBINDD_GETSIDALIASES to the new API

commit ce42ea3ab8c69a3f650d4c9bc787e4805aad928d
Author: Volker Lendecke 
Date:   Tue Aug 4 15:54:05 2009 -0400

s3:winbind: Add async wb_lookupuseraliases

commit f09a95aaff4542df4225f3828a0d737497f0f2e8
Author: Volker Lendecke 
Date:   Sun Aug 2 17:17:27 2009 +0200

s3:winbind: Make parse_sidlist take a const char *

commit ff3ce9016a43906df55a0922f0697c91d255de88
Author: Volker Lendecke 
Date:   Sun Aug 2 16:52:19 2009 +0200

s3:winbind: Make wcache_lookup_useraliases available publically

commit bd9d7f75e352985f1b0e0785f0ba94dea19d2601
Author: Volker Lendecke 
Date:   Tue Aug 4 15:41:40 2009 -0400

s3:winbind: Convert WINBINDD_GETPWUID to the new API

commit 5bbb7a0d143b34b6a2a2c4adb1114120cddd74bf
Author: Volker Lendecke 
Date:   Tue Aug 4 15:37:54 2009 -0400

s3:winbind: Convert WINBINDD_GETPWNAM to the new API

commit 9dc401a20ec608d4d8ae25fb4e81c462e9ced415
Author: Volker Lendecke 
Date:   Tue Aug 4 15:35:24 2009 -0400

s3:winbind: Convert WINBINDD_GETPWSID to the new API

commit afc82444fd367e8b8541e4a41a86966a288ed2ef
Author: Volker Lendecke 
Date:   Tue Aug 4 15:32:11 2009 -0400

s3:winbind: Add async wb_getpwsid

commit 0418d38bc80dc8680834875629a3df8e1734b885
Author: Volker Lendecke 
Date:   Tue Aug 4 15:31:49 2009 -0400

s3:winbind: Make fillup_pw_field publically available

commit 7077492778dbda30e5f865ae1d0ab0237e00f54f
Author: Volker Lendecke 
Date:   Tue Aug 4 15:23:13 2009 -0400

s3:winbind: Add async wb_queryuser

commit 360227a0feb443fbbcc420295d5666da5823685a
Author: Volker Lendecke 
Date:   Sat Aug 1 10:20:13 2009 -0400

s3:winbind: Make wcache_query_user externally visible

commit 10685b37d4dc16dc75c48c08937f003af4968a0c
Author: Volker Lendecke 
Date:   Tue Aug 4 14:22:17 2009 -040